@@ -36,9 +36,13 @@ getResponse.default <- function(object, ...) {
 #' @rdname getResponse
 #' @export
 getResponse.lm <- function(object, ...) {
-  responsevar <- deparse(formula(object)[[2]])
-  ans <- model.frame(object$model)[, responsevar]
-  return(ans)
+  if(!is.null(object[["x"]])){
+    object[["x"]]
+  }
+  else{
+    responsevar <- deparse(formula(object)[[2]])
+    model.frame(object$model)[, responsevar]
+  }
 }
 
 #' @rdname getResponse
@@ -49,7 +53,7 @@ getResponse.Arima <- function(object, ...) {
   } else {
     series.name <- object$series
     if (is.null(series.name)) {
-      stop("missing original time series")
+      return(NULL)
     } else {
       x <- try(eval.parent(parse(text = series.name)), silent = TRUE)
       if (is.element("try-error", class(x))) { # Try one level further up the chain
@@ -123,4 +127,4 @@ getResponse.baggedModel <- function(object, ...) {
     return(NULL)
   }
   return(as.ts(y))
-}
\ No newline at end of file
+}
