@@ -15,7 +15,7 @@ mlmsplit <- function(x, index=NULL) {
   class(x) <- "lm"
   y <- attr(x$terms, "response")
 
-  yName <- colnames(x$model[[y]])[index]
+  yName <- make.names(colnames(x$model[[y]])[index])
   x$model[[y]] <- x$model[[y]][, index]
   colnames(x$model)[y] <- yName
   attr(x$model, "terms") <- terms(reformulate(attr(x$terms, "term.labels"), response = yName), data = x$model)
@@ -59,7 +59,7 @@ mlmsplit <- function(x, index=NULL) {
 #' time series attributes of the original data will be ignored.
 #' @param ... Other arguments passed to \code{\link[forecast]{forecast.lm}()}.
 #' @inheritParams forecast
-#' 
+#'
 #' @return An object of class "\code{mforecast}".
 #'
 #' The function \code{summary} is used to obtain and print a summary of the
@@ -215,7 +215,7 @@ print.mforecast <- function(x, ...) {
 #' @seealso \code{\link[forecast]{plot.forecast}}, \code{\link[stats]{plot.ts}}
 #' @references Hyndman and Athanasopoulos (2018) \emph{Forecasting: principles
 #' and practice}, 2nd edition, OTexts: Melbourne, Australia.
-#' \url{https://OTexts.org/fpp2/}
+#' \url{https://otexts.com/fpp2/}
 #' @keywords ts
 #' @examples
 #' library(ggplot2)
@@ -248,15 +248,21 @@ plot.mforecast <- function(x, main=paste("Forecasts from", unique(x$method)), xl
 
 #' @export
 summary.mforecast <- function(object, ...) {
-  cat(paste("\nForecast method:", unique(object$method)))
+  class(object) <- c("summary.mforecast", class(object))
+  object
+}
+
+#' @export
+print.summary.mforecast <- function(x, ...) {
+  cat(paste("\nForecast method:", unique(x$method)))
   cat(paste("\n\nModel Information:\n"))
-  print(object$model)
+  print(x$model)
   cat("\nError measures:\n")
-  print(accuracy(object))
-  if (is.null(object$forecast)) {
+  print(accuracy(x))
+  if (is.null(x$forecast)) {
     cat("\n No forecasts\n")
   } else {
     cat("\nForecasts:\n")
-    print(object)
+    NextMethod()
   }
 }
